==> react-atom-button-1.60.0.tgz: package/lib/Button.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';

var Button = function Button(_ref) {
  var children = _ref.children,
      href = _ref.href,
      target = _ref.target,
      disabled = _ref.disabled,
      isSubmit = _ref.isSubmit,
      isButton = _ref.isButton,
      link = _ref.link,
      Link = _ref.linkFactory,
      attrs = _objectWithoutPropertiesLoose(_ref, ["children", "href", "target", "disabled", "isSubmit", "isButton", "link", "linkFactory"]);

  if (isSubmit) attrs.type = 'submit';
  if (isButton) attrs.type = 'button';
  var defaultRel = target === '_blank' ? 'noopener' : undefined;
  var rel = attrs.rel || defaultRel;
  return link ? /*#__PURE__*/_jsx(Link, _extends({}, attrs, {
    href: href,
    target: target,
    rel: rel,
    children: children
  })) : /*#__PURE__*/_jsx("button", _extends({}, attrs, {
    disabled: disabled,
    children: children
  }));
};

Button.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Content to be included in the button
   */
  children: PropTypes.node,

  /**
   * HTML element: if true, render a link. Otherwise render a button
   */
  link: PropTypes.bool,

  /**
   * URL to be added on the HTML link
   */
  href: PropTypes.string,

  /**
   * Target to be added on the HTML link
   */
  target: PropTypes.string,

  /**
   * Disable: faded with no interaction.
   */
  disabled: PropTypes.bool,

  /**
   * Factory used to create navigation links
   */
  linkFactory: PropTypes.func
} : {};
Button.defaultProps = {
  // eslint-disable-next-line react/prop-types
  linkFactory: function linkFactory(_temp) {
    var _ref2 = _temp === void 0 ? {} : _temp,
        children = _ref2.children,
        rest = _objectWithoutPropertiesLoose(_ref2, ["children"]);

    return /*#__PURE__*/_jsx("a", _extends({}, rest, {
      children: children
    }));
  }
};
export default Button;

==> react-atom-button-1.65.0.tgz: package/lib/Button.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import { forwardRef } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";

var Button = function Button(_ref) {
  var children = _ref.children,
      href = _ref.href,
      target = _ref.target,
      disabled = _ref.disabled,
      isSubmit = _ref.isSubmit,
      isButton = _ref.isButton,
      link = _ref.link,
      Link = _ref.linkFactory,
      forwardingRef = _ref.forwardingRef,
      attrs = _objectWithoutPropertiesLoose(_ref, ["children", "href", "target", "disabled", "isSubmit", "isButton", "link", "linkFactory", "forwardingRef"]);

  if (isSubmit) attrs.type = 'submit';
  if (isButton) attrs.type = 'button';
  var defaultRel = target === '_blank' ? 'noopener' : undefined;
  var rel = attrs.rel || defaultRel;
  return link ? /*#__PURE__*/_jsx(Link, _extends({}, attrs, {
    href: href,
    target: target,
    rel: rel,
    ref: forwardingRef,
    children: children
  })) : /*#__PURE__*/_jsx("button", _extends({}, attrs, {
    disabled: disabled,
    ref: forwardingRef,
    children: children
  }));
};

Button.defaultProps = {
  // eslint-disable-next-line react/prop-types
  linkFactory: /*#__PURE__*/forwardRef(function (_ref2, ref) {
    var children = _ref2.children,
        props = _objectWithoutPropertiesLoose(_ref2, ["children"]);

    return /*#__PURE__*/_jsx("a", _extends({}, props, {
      ref: ref,
      children: children
    }));
  })
};
export default Button;
